@@ -1,9 +1,12 @@
 names = [
     "test_code_quality.jl"
+    "test_cnumber.jl"
     "test_fock.jl"
     "test_nlevel.jl"
     "test_spin.jl"
+    "test_phase_space.jl"
     "test_average.jl"
+    "test_utils.jl"
     "test_numeric_conversion.jl"
     "test_cluster.jl"
     "test_index_basic.jl"
